==> tencentcloud-sdk-java-3.1.210-sources.jar: com/tencentcloudapi/asr/v20190614/models/CloseAsyncRecognitionTaskRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.asr.v20190614.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class CloseAsyncRecognitionTaskRequest extends AbstractModel{

    /**
    * 语音流异步识别任务的唯一标识，在创建任务时会返回
    */
    @SerializedName("TaskId")
    @Expose
    private Long TaskId;

    /**
     * Get 语音流异步识别任务的唯一标识，在创建任务时会返回 
     * @return TaskId 语音流异步识别任务的唯一标识，在创建任务时会返回
     */
    public Long getTaskId() {
        return this.TaskId;
    }

    /**
     * Set 语音流异步识别任务的唯一标识，在创建任务时会返回
     * @param TaskId 语音流异步识别任务的唯一标识，在创建任务时会返回
     */
    public void setTaskId(Long TaskId) {
        this.TaskId = TaskId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "TaskId", this.TaskId);

    }
}

==> tencentcloud-sdk-java-3.1.920-sources.jar: com/tencentcloudapi/asr/v20190614/models/CloseAsyncRecognitionTaskRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.asr.v20190614.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class CloseAsyncRecognitionTaskRequest extends AbstractModel {

    /**
    * 语音流异步识别任务的唯一标识，在创建任务时会返回
    */
    @SerializedName("TaskId")
    @Expose
    private Long TaskId;

    /**
     * Get 语音流异步识别任务的唯一标识，在创建任务时会返回 
     * @return TaskId 语音流异步识别任务的唯一标识，在创建任务时会返回
     */
    public Long getTaskId() {
        return this.TaskId;
    }

    /**
     * Set 语音流异步识别任务的唯一标识，在创建任务时会返回
     * @param TaskId 语音流异步识别任务的唯一标识，在创建任务时会返回
     */
    public void setTaskId(Long TaskId) {
        this.TaskId = TaskId;
    }

    public CloseAsyncRecognitionTaskRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public CloseAsyncRecognitionTaskRequest(CloseAsyncRecognitionTaskRequest source) {
        if (source.TaskId != null) {
            this.TaskId = new Long(source.TaskId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "TaskId", this.TaskId);

    }
}
